<?php

// +---------------------------------------------------------------------------+
// | Menu Plugin 1.2 for Geeklog - The Ultimate Weblog                         |
// +---------------------------------------------------------------------------+
// | install.php                                                               |
// |                                                                           |
// | This file installs and removes the data structures for the Menu           |
// | plugin for Geeklog.                                                       |
// +---------------------------------------------------------------------------+
// | Copyright (C) 2002 by the following authors:                              |
// |                                                                           |
// | Authors: Tom Willett        - tomw@pigstye.net                            |
// +---------------------------------------------------------------------------+
// |                                                                           |
// | This program is free software; you can redistribute it and/or             |
// | modify it under the terms of the GNU General Public License               |
// | as published by the Free Software Foundation; either version 2            |
// | of the License, or (at your option) any later version.                    |
// |                                                                           |
// | This program is distributed in the hope that it will be useful,           |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
// | GNU General Public License for more details.                              |
// |                                                                           |
// | You should have received a copy of the GNU General Public License         |
// | along with this program; if not, write to the Free Software Foundation,   |
// | Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.           |
// |                                                                           |
// +---------------------------------------------------------------------------+
//

require_once('../../../lib-common.php');
$langfile = $_CONF['path'] . 'plugins/menu/language/' . $_CONF['language'] . '.php';
if (file_exists ($langfile)) {
    require_once ($langfile);
} else {
    require_once ($_CONF['path'] . 'plugins/menu/language/english.php');
}

// Only let Root users access this page
if (!SEC_inGroup('Root')) {
    // Someone is trying to illegally access this page
    COM_errorLog("Someone has tried to illegally access the Menu install/uninstall page.  User id: {$_USER['uid']}, Username: {$_USER['username']}, IP: $REMOTE_ADDR",1);
    $display = COM_siteHeader();
    $display .= COM_startBlock($LANG_MNU['access_denied']);
    $display .= $LANG_MNU['access_denied_msg'];
    $display .= COM_endBlock();
    $display .= COM_siteFooter(true);
    echo $display;
    exit;
}
 
/**
* Puts the datastructures for this plugin into the Geeklog database
*
*/
function plugin_install()
{
    global $_TABLES, $_CONF, $_USER;

    COM_errorLog('Attempting to install the Menu Plugin',1);

    // Installs the menu plugin

    $createsql = "CREATE TABLE mnu_index ("
	. "m_id int(10) NOT NULL Auto_Increment,"
	. "m_type tinyint(1) unsigned NOT NULL default '0',"
	. "m_pos tinyint(1) unsigned NOT NULL default '0',"
	. "m_label varchar(40) NOT NULL default '',"
	. "m_url varchar(255) NOT NULL default '',"
	. "group_id mediumint(8) unsigned NOT NULL default '1',"
	. "owner_id mediumint(8) unsigned NOT NULL default '1',"
  	. "perm_owner tinyint(1) unsigned NOT NULL default '3',"
  	. "perm_group tinyint(1) unsigned NOT NULL default '3',"
  	. "perm_members tinyint(1) unsigned NOT NULL default '2',"
  	. "perm_anon tinyint(1) unsigned NOT NULL default '2',"
    . "PRIMARY KEY (m_id)"
    . ")";

    COM_errorLog("Attempting to create table mnu_index for menu plugin", 1);
    DB_query($createsql,1);
    if (DB_error()) {
        return false;
    }

	COM_errorLog("Adding sample menu",1);
	DB_query("INSERT INTO mnu_index VALUES (1,1,1,'Home','http:/index.php',1,1,2,2,2,2)");
	DB_query("INSERT INTO mnu_index VALUES (3,3,2,'','',1,1,2,2,2,2)");
	DB_query("INSERT INTO mnu_index VALUES (4,4,10,'User','',1,1,2,2,2,2)");
	DB_query("INSERT INTO mnu_index VALUES (5,5,11,'Admin','',1,1,2,2,2,2)");
	DB_query("INSERT INTO mnu_index VALUES (9,2,3,'','',1,1,2,2,2,2)");
	DB_query("INSERT INTO mnu_index VALUES (10,1,5,'Geeklog','http://geeklog.sf.net',1,1,2,2,2,2)");
	
    COM_errorLog('...success',1);

    $createsql = "CREATE TABLE mnu_user ("
	. "m_id int(10) NOT NULL Auto_Increment,"
	. "owner_id mediumint(8) default '1',"
	. "m_type tinyint(1) unsigned NOT NULL default '0',"
	. "m_pos tinyint(1) unsigned NOT NULL default '0',"
	. "m_label varchar(40) NOT NULL default '',"
	. "m_url varchar(255) NOT NULL default '',"
    . "PRIMARY KEY (m_id)"
    . ")";

    COM_errorLog("Attempting to create table mnu_user for menu plugin", 1);
    DB_query($createsql,1);
    if (DB_error()) {
        return false;
    }

    COM_errorLog('...success',1);

	// Insert Menu Block
	DB_query("INSERT INTO {$_TABLES['blocks']} (is_enabled, name, type, title,tid,blockorder,onleft,phpblockfn,owner_id)"
	               . " VALUES (0,'menu_plugin','phpblock','Menu','all',0,1,'phpblock_menu_plugin'," . $_USER['uid'] . ")");

    // Create the menu admin security group
    COM_errorLog("Attempting to create Menu admin group", 1);
    DB_query("INSERT INTO {$_TABLES['groups']} (grp_name, grp_descr) "
        . "VALUES ('Menu Admin', 'Users in this group can administer the Menu plugin')",1);
    if (DB_error()) {
        uninstall_menu();
        return false;
        exit;
    }
    COM_errorLog('...success',1);

    // Save the grp id for later uninstall
    COM_errorLog('About to save group_id to vars table for use during uninstall',1);
    DB_query("INSERT INTO {$_TABLES['vars']} VALUES ('menu_group_id', LAST_INSERT_ID())",1);
    if (DB_error()) {
        uninstall_menu();
        return false;
        exit;
    }
    COM_errorLog('...success',1);

    $group_id = DB_getItem($_TABLES['vars'], 'value', "name = 'menu_group_id'");

    // Add menu features
    COM_errorLog('Attempting to add menu.edit feature',1);
    DB_query("INSERT INTO {$_TABLES['features']} (ft_name, ft_descr) "
        . "VALUES ('menu.edit','Access to Menu editor')",1);
    if (DB_error()) {
        uninstall_menu();
        return false;
        exit;
    }
    $edit_id = DB_insertId();
    COM_errorLog('...success',1);

    COM_errorLog('Attempting to add menu.admin feature',1);
    DB_query("INSERT INTO {$_TABLES['features']} (ft_name, ft_descr) "
        . "VALUES ('menu.admin','Ability to administer menu')",1);
    if (DB_error()) {
        uninstall_menu();
        return false;
        exit;
    }
    $admin_id = DB_insertId();
    COM_errorLog('...success',1);

    // Now add the features to the group
    COM_errorLog('Attempting to give Menu Admin group access to menu.edit feature',1);
    DB_query("INSERT INTO {$_TABLES['access']} (acc_ft_id, acc_grp_id) VALUES ($edit_id, $group_id)");
    DB_query("INSERT INTO {$_TABLES['access']} (acc_ft_id, acc_grp_id) VALUES ($admin_id, $group_id)");
    if (DB_error()) {
        uninstall_menu();
        return false;
        exit;
    }
    COM_errorLog('...success',1);

    // OK, now give Root users access to this plugin now! NOTE: Root group should always be 1
    COM_errorLog('Attempting to give all users in Root group access menu admin group',1);
    DB_query("INSERT INTO {$_TABLES['group_assignments']} VALUES ($group_id, NULL, 1)");
    if (DB_error()) {
        uninstall_menu();
        return false;
        exit;
    }
    COM_errorLog('...success',1);

    // Register the plugin with Geeklog
    COM_errorLog('Registering Menu plugin with Geeklog', 1);
    DB_delete($_TABLES['plugins'],'pi_name','menu');
    DB_query("INSERT INTO {$_TABLES['plugins']} (pi_name, pi_version, pi_gl_version, pi_homepage, pi_enabled) "
        . "VALUES ('menu', '1.1', '1.3.6', 'http://www.pigstye.net/index.php', 1)");
    DB_query("INSERT INTO {$_TABLES['vars']} VALUES ('menu','1')");

    if (DB_error()) {
        uninstall_menu();
        return false;
        exit;
    }
    COM_errorLog('...success',1);
    COM_errorLog('Succesfully installed the Menu Plugin!',1);

    return true;
}

/**
* Removes the datastructures for this plugin from the Geeklog database
*
* This may get called by the install routine to undue anything done to this
* point.  To do that, $steps will have a list of steps to undo
*
*/  
function uninstall_menu()
{
    global $_TABLES;

    // Uninstalls the menu plugin

    // Remove the menu tables
    COM_errorLog('Dropping menu table',1);
    DB_query("DROP TABLE mnu_index",1);
    COM_errorLog('...success',1);
    COM_errorLog('Dropping menu user table',1);
    DB_query("DROP TABLE mnu_user",1);
    COM_errorLog('...success',1);

    // Remove security for this plugin

    // Remove the menu admin group
    $grp_id = DB_getItem($_TABLES['vars'], 'value', "name = 'menu_group_id'");

    COM_errorLog('Attempting to remove the Menu Admin Group', 1);
    DB_query("DELETE FROM {$_TABLES['groups']} WHERE grp_id = $grp_id",1);
    COM_errorLog('...success',1);

    // Remove related features
    $edit_id = DB_getItem($_TABLES['features'], 'ft_id', "ft_name = 'menu.edit'");
    $admin_id = DB_getItem($_TABLES['features'], 'ft_id', "ft_name = 'menu.admin'");

    // Remove access to those features 
    COM_errorLog('Attempting to remove rights to menu.view from all groups',1);
    DB_query("DELETE FROM {$_TABLES['access']} WHERE acc_ft_id = $view_id",1);
    COM_errorLog('...success',1);

    // Remove access to those features 
    COM_errorLog('Attempting to remove rights to menu.edit from all groups',1);
    DB_query("DELETE FROM {$_TABLES['access']} WHERE acc_ft_id = $edit_id",1);
    COM_errorLog('...success',1);

    // Remove access to those features 
    COM_errorLog('Attempting to remove rights to menu.admin from all groups',1);
    DB_query("DELETE FROM {$_TABLES['access']} WHERE acc_ft_id = $admin_id",1);
    COM_errorLog('...success',1);

    // Remove root users from the group
    COM_errorLog('Attempting to remove root users from admin of menu');
    DB_query("DELETE FROM {$_TABLES['group_assignments']} WHERE ug_main_grp_id = $grp_id",1);
    COM_errorLog('...success',1);

    COM_errorLog('Attempting to remove the menu.edit feature',1);
    DB_query("DELETE FROM {$_TABLES['features']} WHERE ft_id = $view_id",1);
    COM_errorLog('...success',1);

    COM_errorLog('Attempting to remove the menu.edit feature',1);
    DB_query("DELETE FROM {$_TABLES['features']} WHERE ft_id = $edit_id",1);
    COM_errorLog('...success',1);

    COM_errorLog('Attempting to remove the menu.admin feature',1);
    DB_query("DELETE FROM {$_TABLES['features']} WHERE ft_id = $admin_id",1);
    COM_errorLog('...success',1);

    COM_errorLog('Attempting to remove the group id from the vars table',1);
    DB_query("DELETE FROM {$_TABLES['vars']} WHERE name = 'menu_group_id'",1);
    COM_errorLog('success',1);


    // Unregister the plugin with Geeklog
    COM_errorLog('Attempting to unregister the plugin from Geeklog',1);
    DB_query("DELETE FROM {$_TABLES['plugins']} WHERE pi_name = 'menu'",1);
    DB_query("DELETE FROM {$_TABLES['vars']} WHERE name = 'menu'");
    COM_errorLog('...success',1);

    COM_errorLog('Finished uninstalling Menu',1);
    return true;
}

/* 
* Upgrade from 1.0 to 1.5
* 
*/
function plugin_upgrade_menu()
{
    global $_TABLES;
    
    DB_query("UPDATE {$_TABLES['plugins']} SET pi_version='1.5' WHERE pi_name = 'menu'",1);    
}
/* 
* Main Function
*/

$display = COM_siteHeader();
$display .= COM_startBlock($LANG_MNU['install_header']);

if ($action == 'install') {
    // Install this plugin
    if (plugin_install()) {
		$T = new Template($_CONF['path'] . 'plugins/menu/templates');
		$T->set_file('install', 'install.thtml');
		$T->set_var('site_url',$_CONF['site_url']);
		$T->set_var('site_admin_url',$_CONF['site_admin_url']);
		$T->set_var('install_header',$LANG_MNU['installed']);
		$T->set_var('installmsg1',$LANG_MNU['installation_complete']);
		$T->set_var('installmsg2',$LANG_MNU['installation_complete_msg']);
		$T->set_var('btnmsg',$LANG_MNU['uninstall']);
		$T->set_var('action','uninstall');
		$T->parse('output','install');
        $display .= $T->finish($T->get_var('output'));
    } else {
        // Error occured
		$T = new Template($_CONF['path'] . 'plugins/menu/templates');
		$T->set_file('install', 'install.thtml');
		$T->set_var('site_url',$_CONF['site_url']);
		$T->set_var('site_admin_url',$_CONF['site_admin_url']);
		$T->set_var('install_header',$LANG_MNU['notinstalled']);
		$T->set_var('installmsg1',$LANG_MNU['installation_failed']);
		$T->set_var('installmsg2',$LANG_MNU['installation_failed_msg']);
		$T->set_var('btnmsg',$LANG_MNU['tryagain']);
		$T->set_var('action','install');
		$T->parse('output','install');
        $display .= $T->finish($T->get_var('output'));
        $display .= 'installation_failed_msg';
    }   
} else if ($action == 'uninstall') {
    // Uninstall plugin
    if (uninstall_menu()) {
        // Uninstall worked
		$T = new Template($_CONF['path'] . 'plugins/menu/templates');
		$T->set_file('install', 'install.thtml');
		$T->set_var('site_url',$_CONF['site_url']);
		$T->set_var('site_admin_url',$_CONF['site_admin_url']);
		$T->set_var('install_header',$LANG_MNU['notinstalled']);
		$T->set_var('installmsg1',$LANG_MNU['uninstall_complete_msg']);
		$T->set_var('installmsg2',$LANG_MNU['uninstall_complete_msg2']);
		$T->set_var('btnmsg',$LANG_MNU['install']);
		$T->set_var('action','install');
		$T->parse('output','install');
        $display .= $T->finish($T->get_var('output'));
    } else {
        // Uninstall failed
		$T = new Template($_CONF['path'] . 'plugins/menu/templates');
		$T->set_file('install', 'install.thtml');
		$T->set_var('site_url',$_CONF['site_url']);
		$T->set_var('site_admin_url',$_CONF['site_admin_url']);
		$T->set_var('install_header',$LANG_MNU['installed']);
		$T->set_var('installmsg1',$LANG_MNU['uninstall_failed']);
		$T->set_var('installmsg2',$LANG_MNU['uninstall_failed_msg']);
		$T->set_var('btnmsg',$LANG_MNU['tryagain']);
		$T->set_var('action','uninstall');
		$T->parse('output','install');
        $display .= $T->finish($T->get_var('output'));
    }
} else {
    if (DB_count($_TABLES['vars'], 'name', 'menu') == 0) {
		$T = new Template($_CONF['path'] . 'plugins/menu/templates');
		$T->set_file('install', 'install.thtml');
		$T->set_var('site_url',$_CONF['site_url']);
		$T->set_var('site_admin_url',$_CONF['site_admin_url']);
		$T->set_var('install_header',$LANG_MNU['notinstalled']);
		$T->set_var('installmsg1',$LANG_MNU['notinstalled_msg']);
		$T->set_var('installmsg2',"");
		$T->set_var('btnmsg',$LANG_MNU['install']);
		$T->set_var('action','install');
		$T->parse('output','install');
        $display .= $T->finish($T->get_var('output'));
    } else {
		$T = new Template($_CONF['path'] . 'plugins/menu/templates');
		$T->set_file('install', 'install.thtml');
		$T->set_var('site_url',$_CONF['site_url']);
		$T->set_var('site_admin_url',$_CONF['site_admin_url']);
		$T->set_var('install_header',$LANG_MNU['installed']);
		$T->set_var('installmsg1',$LANG_MNU['installed_msg']);
		$T->set_var('installmsg2',$LANG_MNU['installed_msg2']);
		$T->set_var('btnmsg',$LANG_MNU['uninstall']);
		$T->set_var('action','uninstall');
		$T->parse('output','install');
        $display .= $T->finish($T->get_var('output'));
    }
} 
 
$display .= COM_endBlock();
$display .= COM_siteFooter(true);

echo $display;

?>